EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Connectors_GetCachedResponse',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'DataRow',
    /* DataTableNames_Csv      */ 'ConnectorResponses',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets the cached response with the matching hash if possible.'
GO

IF OBJECT_ID('[Connectors_GetCachedResponse]') IS NOT NULL DROP PROCEDURE [Connectors_GetCachedResponse]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Connectors_GetCachedResponse]
(
	@Connector_Id INT,
	@Request_Hash BINARY(32)
)
AS BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	UPDATE [ConnectorResponses]
	   SET [LastUsed_Date] = GETUTCDATE(),
	       [Request_Count] = [Request_Count] + 1
	 WHERE [Connector_Id] = @Connector_Id
	   AND [Request_Hash] = @Request_Hash

	SELECT *
	  FROM [ConnectorResponses]
	 WHERE [Connector_Id] = @Connector_Id
	   AND [Request_Hash] = @Request_Hash

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Connectors_GetCachedResponse] TO [ProGetUser_Role]
GO
